@@ -1,7 +1,11 @@
+#define QT_VERSION_MAJOR    5
+#define QT_VERSION_MINOR    6
+#define QT_VERSION_PATCH    0
+#define QT_VERSION_STR      "5.6.0"
+
 /* Everything */
 /* Compile time features */
 #define QT_LARGEFILE_SUPPORT 64
-#define QT_POINTER_SIZE 4
 
 // Compiler sub-arch support
 
@@ -13,12 +17,6 @@
 # define QT_LINKED_OPENSSL
 #endif
 
-#if defined(QT_NO_ALSA) && defined(QT_ALSA)
-# undef QT_NO_ALSA
-#elif !defined(QT_NO_ALSA) && !defined(QT_ALSA)
-# define QT_NO_ALSA
-#endif
-
 #if defined(QT_NO_IMAGEFORMAT_JPEG) && defined(QT_IMAGEFORMAT_JPEG)
 # undef QT_NO_IMAGEFORMAT_JPEG
 #elif !defined(QT_NO_IMAGEFORMAT_JPEG) && !defined(QT_IMAGEFORMAT_JPEG)
@@ -43,12 +41,6 @@
 # define QT_NO_TABLET
 #endif
 
-#if defined(QT_NO_TSLIB) && defined(QT_TSLIB)
-# undef QT_NO_TSLIB
-#elif !defined(QT_NO_TSLIB) && !defined(QT_TSLIB)
-# define QT_NO_TSLIB
-#endif
-
 #if defined(QT_NO_XINPUT) && defined(QT_XINPUT)
 # undef QT_NO_XINPUT
 #elif !defined(QT_NO_XINPUT) && !defined(QT_XINPUT)
@@ -103,6 +95,12 @@
 # define QT_RUNTIME_XRANDR
 #endif
 
+#if defined(QT_THREADSAFE_CLOEXEC) && defined(QT_NO_THREADSAFE_CLOEXEC)
+# undef QT_THREADSAFE_CLOEXEC
+#elif !defined(QT_THREADSAFE_CLOEXEC) && !defined(QT_NO_THREADSAFE_CLOEXEC)
+# define QT_THREADSAFE_CLOEXEC 1
+#endif
+
 #endif // QT_BOOTSTRAPPED
 
 #define QT_VISIBILITY_AVAILABLE
